# Auth Checker

This repository contains a class that checks if a user has the specified role in their JWT payload
    ([view usage](https://github.com/ncstate-sat/clearance-service/blob/56ac7a89729cff05f840561611ca7aa2186f473f/crud/assignments.py#L74))
